Unreleased changes
------------------


Version 0
---------

0.2.6 / 2023-02-02
~~~~~~~~~~~~~~~~~~
* Remove template artifacts
* Adding functions to generate opt file from DB
* Adding command line tool to generate opt files


0.1.0 / 2021-10-29
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
